<?php

namespace Drupal\Tests\eme\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\eme\Traits\EmeTestTrait;
use Drush\TestTraits\DrushTestTrait;

/**
 * Base class for testing Drush integration.
 */
abstract class DrushTestBase extends BrowserTestBase {

  use DrushTestTrait;
  use EmeTestTrait;

  /**
   * The migration group of the generated migration plugins.
   *
   * @const string
   */
  const TEST_GROUP = 'emegroup';

  /**
   * The migration plugin ID prefix of the generated migration plugins.
   *
   * @const string
   */
  const TEST_PREFIX = 'emi';

  /**
   * A path where the exported module should be saved.
   *
   * @const string
   */
  const TEST_EXPORT_DEST = 'modules/content_migrations';

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node',
    'filter',
    'text',
    'comment',
    'eme',
    'eme_test_module_extension_list',
    'migrate_tools',
  ];

  /**
   * The machine name for the generated module.
   *
   * @var string
   */
  protected $exportedModuleName;

  /**
   * Returns the destination for the exported module.
   *
   * @return string
   *   The destination where the exported module should be saved.
   */
  protected function getMigrateExportDestination(): string {
    return $this->siteDirectory . '/' . static::TEST_EXPORT_DEST;
  }

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    $this->exportedModuleName = 'em_' . basename($this->siteDirectory);
    $site_directory = $this->container->getParameter('app.root') . '/' . $this->siteDirectory;
    $this->assertDirectoryIsWritable($site_directory);
  }

}
